
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter_device_details/flutter_device_details.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';
  bool _isRooted = false;
  TelephonyInfo _teleInfo;
  String _ipAddress;
  PackageInfo _packageInfo;
  AndroidDeviceInfo _androidDeviceInfo;

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      platformVersion = await DeviceDetails.platformVersion;
      print(platformVersion);
      _ipAddress = await DeviceDetails.ipAddress;
      _isRooted = await DeviceDetails.jailbroken;
      _teleInfo = await DeviceDetails.telePhoneInfo;
      _packageInfo = await DeviceDetails.fromPlatform;
      _androidDeviceInfo = await DeviceDetails.androidInfo;
      print('ip Address: $_ipAddress');
      print('Package Name:${ _packageInfo.packageName }');
      print('AndroidID:${ _androidDeviceInfo.androidId}');
      print('Network Operator:${ _teleInfo.simCarrierIdName}');
      print('Is Rooted Device: $_isRooted');
    } on PlatformException {
      platformVersion = 'Platform Exception.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Column(
            children: <Widget>[
              Text('Running on: $_platformVersion\n'),
            ],
          ),
        ),
      ),
    );
  }
}
